import pandas as pd
import joblib
from sklearn.model_selection import train_test_split
from sklearn.ensemble import RandomForestClassifier
from sklearn.metrics import classification_report, confusion_matrix
from sklearn.preprocessing import LabelEncoder
import os


df = pd.read_csv("../Dataset/Linhac24-25_Sportlogiq.csv", encoding="utf-8")

df['is_goal'] = (df['eventname'] == 'goal').astype(int)

#删除无用或无关紧要的列（如gameid、playerid等）
drop_cols = ['gameid', 'playerid', 'eventname', 'compiledgametime']
df.drop(columns=drop_cols, inplace=True, errors='ignore')

categorical_cols = df.select_dtypes(include='object').columns
for col in categorical_cols:
    df[col] = LabelEncoder().fit_transform(df[col].astype(str))

X = df.drop(columns=['is_goal'])
y = df['is_goal']


X_train, X_test, y_train, y_test = train_test_split(
    X, y, test_size=0.2, stratify=y, random_state=42
)


# 使用 class_weight 处理不平衡
model = RandomForestClassifier(
    n_estimators=100,
    random_state=42,
    class_weight='balanced',
    n_jobs=-1
)
model.fit(X_train, y_train)

joblib.dump(model, "../Model/RF2.pkl")
print("模型已保存")




model = joblib.load("../Model/RF2.pkl")

y_pred = model.predict(X_test)

print("=== Classification Report ===")
print(classification_report(y_test, y_pred, digits=4))

print("\n=== Confusion Matrix ===")
print(confusion_matrix(y_test, y_pred))

importances = pd.Series(model.feature_importances_, index=X.columns)
print("\n=== Top 10 Important Features ===")
print(importances.sort_values(ascending=False).head(10))
