import pandas as pd
import seaborn as sns
import matplotlib.pyplot as plt
import matplotlib

matplotlib.rcParams['font.family'] = 'Microsoft YaHei'  # 设置中文字体为微软雅黑
matplotlib.rcParams['axes.unicode_minus'] = False       # 正确显示负号

df = pd.read_csv("Linhac24-25_Sportlogiq.csv")

sns.set(style="whitegrid")

print("数据基本信息：")
print(df.info())
print("\n描述性统计：")
print(df.describe())

print("\n不同事件类型分布：")
print(df['eventname'].value_counts())

plt.figure(figsize=(12, 5))
sns.countplot(data=df, x='eventname', order=df['eventname'].value_counts().index)
plt.xticks(rotation=45)
plt.title("事件类型分布")
plt.tight_layout()
plt.show()


plt.figure(figsize=(8, 4))
sns.histplot(df['xg_allattempts'], bins=30, kde=True)
plt.title("xG 分布")
plt.xlabel("xG 值")
plt.tight_layout()
plt.show()


corr = df[['compiledgametime', 'xadjcoord', 'yadjcoord', 'xg_allattempts']].corr()
plt.figure(figsize=(6, 4))
sns.heatmap(corr, annot=True, cmap='coolwarm')
plt.title("数值型字段相关性")
plt.tight_layout()
plt.show()


df['event_minute'] = df['compiledgametime'] // 60
minute_event_count = df.groupby('event_minute').size()

plt.figure(figsize=(10, 4))
minute_event_count.plot(kind='bar')
plt.title("每分钟事件数量")
plt.xlabel("分钟")
plt.ylabel("事件数")
plt.tight_layout()
plt.show()



